pageinfo = [[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1715027042,0,0,0,null],
	[1398282942,0,0,0,null],
	[1715027042,0,0,0,null],
	[1398282942,0,0,0,null],
	[1398224028,0,0,0,null],
	[1398282942,0,0,0,null],
	[1398224028,0,0,0,null],
	[1715027042,0,0,0,null],
	[1716915102,0,0,0,null],
	[1398282942,0,0,0,null],
	[1716915102,0,0,0,null],
	[1716915102,0,0,0,null],
	[1398282942,0,0,0,null],
	[1398282942,0,0,0,null],
	[1716915102,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null],
	[1753292994,0,0,0,null]];
pagedata = [ ["./3-way_merge_concepts.html","3-way Merge Concepts","A merge session helps you combine separate sets of changes into a new version of the data, accommodating both sets of changes.","./images/zoomimage.jpg"],
["./archive_files.html","Archive Files","Archives are files that contain other files, such as .zip.  Beyond Compare displays them as folders, with a zipper icon, but by default treat...","./images/zoomimage.jpg"],
["./bcclipmain.html","Clipboard Compare Overview","Clipboard Compare runs in the background, keeping track of every time the Windows clipboard is updated with text.  It appears in the Windows ...","./images/zoomimage.jpg"],
["./bcclipoptions.html","Clipboard Compare Options","These options control the behavior of Clipboard Compare.","./images/zoomimage.jpg"],
["./bcshellex.html","Explorer Integration","Commands for launching various types of comparisons can be added to the Windows Explorer context menu.","./images/zoomimage.jpg"],
["./calling_bc_from_other_applications.html","Calling Beyond Compare from Other Applications","As you would expect, Beyond Compare&#39;s setup program creates shortcuts to the main executable file, such as:","./images/zoomimage.jpg"],
["./commandsbc.html","Common Commands","The main menu changes depending on what kind of view is active.  However, the commands listed below are common across different view types.","./images/zoomimage.jpg"],
["./commandsbcmac.html","Common Commands","The main menu changes depending on what kind of view is active.  However, the commands listed below are common across different view types.","./images/zoomimage.jpg"],
["./commandsdir.html","Folder Compare Commands","Following is a description of the Folder Compare commands, in addition to the common commands.  Most of these commands are available as toolb...","./images/zoomimage.jpg"],
["./commandsdirmerge.html","Folder Merge Commands","Following is a description of the Folder Merge commands, in addition to the common commands.  Most of these commands are available as toolbar...","./images/zoomimage.jpg"],
["./commandsdirsync.html","Folder Sync Commands","Following is a description of the Folder Sync commands, in addition to the common commands.  Most of these commands are available as toolbar ...","./images/zoomimage.jpg"],
["./commandshex.html","Hex Compare Commands","Following is a description of the Hex Compare commands, in addition to the common commands.  Most of these commands are available as toolbar ...","./images/zoomimage.jpg"],
["./commandshome.html","Home Commands","Following is a description of the Home commands, in addition to the common commands.","./images/zoomimage.jpg"],
["./commandsmedia.html","Media Compare Commands","Following is a description of the Media Compare commands, in addition to the common commands.  Most of these commands are available as toolba...","./images/zoomimage.jpg"],
["./commandspix.html","Picture Compare Commands","Following is a description of the Picture Compare commands, in addition to the common commands.  Most of these commands are available as tool...","./images/zoomimage.jpg"],
["./commandsreg.html","Registry Compare Commands","Following is a description of the Registry Compare commands, in addition to the common commands.  Most of these commands are available as too...","./images/zoomimage.jpg"],
["./commandstable.html","Table Compare Commands","Following is a description of the Table Compare commands, in addition to the common commands.  Most of these commands are available as toolba...","./images/zoomimage.jpg"],
["./commandstext.html","Text Compare Commands","Following is a description of the Text Compare commands, in addition to the common commands.  Most of these commands are available as toolbar...","./images/zoomimage.jpg"],
["./commandstextedit.html","Text Edit Commands","Following is a description of the Text Edit commands, in addition to the common commands.  Most of these commands are available as toolbar bu...","./images/zoomimage.jpg"],
["./commandstextmerge.html","Text Merge Commands","Following is a description of the Text Merge commands, in addition to the common commands.  Most of these commands are available as toolbar b...","./images/zoomimage.jpg"],
["./commandstextpatch.html","Text Patch Commands","Following is a description of the Text Patch commands, in addition to the common commands.  Most of these commands are available as toolbar b...","./images/zoomimage.jpg"],
["./commandsver.html","Version Compare Commands","Following is a description of the Version Compare commands, in addition to the common commands.  Most of these commands are available as tool...","./images/zoomimage.jpg"],
["./commands_reference.html","Commands Reference","This part of the documentation describes the commands available in menus and on the toolbar for each view type.","./images/zoomimage.jpg"],
["./command_line_reference.html","Command Line Reference","Command line executable files Executable Meaning BCompare.exe  bcompare   This is the main application.  Only one copy will run at ...","./images/zoomimage.jpg"],
["./dir_filtering_the_view.html","Filtering the Folder Compare View","There are three overall type of filters you can use to control a Folder Compare session&#39;s scope:  File Filters that include or exclude files ...","./images/zoomimage.jpg"],
["./dir_how_to_compare.html","How to Compare in the Folder Compare","There are several ways to compare folders and files.","./images/zoomimage.jpg"],
["./dir_merge_understanding_the_display.html","Understanding the Folder Merge Display","The Folder Merge display uses color cues to highlight the differences between the base folders.  By default, the color meanings are:","./images/zoomimage.jpg"],
["./dir_reconciling_differences.html","Reconciling Differences in the Folder Compare","A Folder Compare session provides commands, such as Copy, Move, Delete and Synchronize, to help you reconcile differences on the folder level.&#38;nbs...","./images/zoomimage.jpg"],
["./dir_sync_how_to_sync.html","How to Sync in the Folder Sync","Setting sync parameters In the upper part of the view, specify the Left folder and Right folder involved.  Either or both base folders may be...","./images/zoomimage.jpg"],
["./dir_sync_understanding_the_display.html","Understanding the Folder Sync Display","Sync actions    Right file will be copied to the left    Left file will be copied to the right    Left file will be ...","./images/zoomimage.jpg"],
["./dir_understanding_the_display.html","Understanding the Folder Compare Display","The Folder Compare display uses color cues to highlight the differences between the two base folders.  By default, the color meanings are:","./images/zoomimage.jpg"],
["./display_filters.html","Display Filters","Display filters limit the view to certain comparison results.  For example, you can pick Show Differences  to hide all the matching file...","./images/zoomimage.jpg"],
["./dlgbrowsemachine.html","Selecting a Remote Registry","If the remote computer you want to connect with does not appear in the list, you may need to do the following:","./images/zoomimage.jpg"],
["./dlgdiralignwithitem.html","Editing an Alignment Override","Fill in the Align left file (or folder) and with right file (or folder) edits.","./images/zoomimage.jpg"],
["./dlgdirfind.html","Finding Filenames","To locate a specific file in a folder view, pick Search &#62; Find Filename .","./images/zoomimage.jpg"],
["./dlgdirotherfilteritem.html","Editing an Other Filter Item","To filter by date Pick Older than or Newer than. If the Day(s) ago checkbox is marked, this filter will be the number of whole days relative to 12...","./images/zoomimage.jpg"],
["./dlgexport.html","Exporting Settings","You can selectively save your program settings, in order to transfer them to another computer, upgrade to a newer version, or share them with anot...","./images/zoomimage.jpg"],
["./dlgfileformatmanager.html","File Format Management","Pick Tools &#62; File Formats  to see and manage the entire list of file formats.","./images/zoomimage.jpg"],
["./dlgimport.html","Importing Settings","You can import settings that were previously exported from Beyond Compare, even an older version like Beyond Compare 3.","./images/zoomimage.jpg"],
["./dlgnag.html","How to Register","Step 1 - Try It You can use the program free for 30 days to see if it suits your needs.  If you use it beyond 30 days you are obliged to pay ...","./images/zoomimage.jpg"],
["./dlgopenwithitem.html","Editing an Open With Item","Enter a name in the Description edit to appear on the Open With menu.","./images/zoomimage.jpg"],
["./dlgprofilebrowse.html","Browsing Using Profiles","In general, wherever folders can be used in Beyond Compare, profiles can be used as well.","./images/zoomimage.jpg"],
["./dlgprofilemanager.html","Profile Management","Pick Tools &#62; Profiles to see and manage the entire list of profiles.","./images/zoomimage.jpg"],
["./dlgprogoptions.html","Program Options","To set program preferences Pick Tools &#62; Options  to open the Options dialog. In the list at the left, click the item containing the option...","./images/zoomimage.jpg"],
["./dlgregister.html","How to Unlock Beyond Compare","Beyond Compare is distributed in evaluation mode, allowing you to see if it suits your needs.  Unless you purchase a license, the program wil...","./images/zoomimage.jpg"],
["./dlgreport.html","Reports","Comparison reports allow you to save the information from a comparison to view later without re-running the comparison.  These reports can be...","./images/zoomimage.jpg"],
["./dlgrestore.html","Restoring Factory Defaults","You can restore settings to their factory defaults.","./images/zoomimage.jpg"],
["./dlgsnapshot.html","Saving Snapshots","To save a snapshot Pick Tools &#62; Save Snapshot . Enter the path of the folder tree to be saved.  If you are currently in a folder view, you...","./images/zoomimage.jpg"],
["./dlgsourcecontrolmanager.html","Source Control Integration","Pick Tools &#62; Source Control Integration to associate folders with your SCC-compatible source control application so that Beyond Compare can off...","./images/zoomimage.jpg"],
["./dlgsupport.html","Reporting Problems","If you have found a problem with Beyond Compare, we would like to hear from you!","./images/zoomimage.jpg"],
["./dlgtablecolhandling.html","Editing Column Handling","The Column Handling dialog allows you to set options for each comparison column.  A subset of this dialog is used to set default handling for...","./images/zoomimage.jpg"],
["./dlgtextfindinfiles.html","Finding Text in Files","To locate specific text in multiple files, pick Search &#62; Find in Files .","./images/zoomimage.jpg"],
["./dlgtextgrammaritem.html","Editing a Grammar Item","Pick an existing Element name from the dropdown list or enter your own new name.","./images/zoomimage.jpg"],
["./dlgtextreplacementitem.html","Editing a Text Replacement Item","Specify the Text to find and the Replace with text.","./images/zoomimage.jpg"],
["./dlgworkspacemanager.html","Managing Workspaces","To save your current workspace configuration Pick Session &#62; Save Workspace As. Enter a unique name or pick a saved workspace to be replaced fro...","./images/zoomimage.jpg"],
["./editing_text.html","Editing Text","Each pane of the Text Compare view is a full-featured text editor.  You can enter and edit text like any other text editor, although as you d...","./images/zoomimage.jpg"],
["./file_formats.html","File Formats","Beyond Compare uses file formats to specify how certain types of files are to be handled.  For example, files with a .jpg or .png extension a...","./images/zoomimage.jpg"],
["./file_masks.html","File Masks","A file mask is a pattern of characters and wildcards used to match folder and file names.","./images/zoomimage.jpg"],
["./formatexternalgeneral.html","External Format General Settings","To compare files using another application, define an external format.","./images/zoomimage.jpg"],
["./formathex.html","Hex Format Settings","Hex formats are file formats used by the Hex Compare session type.","./images/zoomimage.jpg"],
["./formathexconversion.html","Hex Format Conversion Settings","The Conversion tab defines how files should be loaded and saved.","./images/zoomimage.jpg"],
["./formathexgeneral.html","Hex Format General Settings","The Mask is a set of file types to be associated with this file format.","./images/zoomimage.jpg"],
["./formatpix.html","Picture Format Settings","Picture formats are file formats used by the Picture Compare session type.","./images/zoomimage.jpg"],
["./formatpixconversion.html","Picture Format Conversion Settings","The Conversion tab defines how files should be loaded.","./images/zoomimage.jpg"],
["./formatpixgeneral.html","Picture Format General Settings","The Mask is a set of file types to be associated with this file format.","./images/zoomimage.jpg"],
["./formattable.html","Table Format Settings","Table formats are file formats used by the Table Compare session type.","./images/zoomimage.jpg"],
["./formattableconversion.html","Table Format Conversion Settings","The Conversion tab defines how files should be loaded and saved.","./images/zoomimage.jpg"],
["./formattablegeneral.html","Table Format General Settings","The Mask is a set of file types to be associated with this file format.","./images/zoomimage.jpg"],
["./formattableregional.html","Table Format Regional Settings","Mark the Use system checkbox to use your system&#39;s Regional Settings.","./images/zoomimage.jpg"],
["./formattabletype.html","Table Format Type Settings","The Type tab defines the syntax of the data file. Mark the Detect checkbox to have the program automatically determine whether fields are separate...","./images/zoomimage.jpg"],
["./formattext.html","Text Format Settings","Text formats are file formats used by the Text Compare and Text Merge session types.","./images/zoomimage.jpg"],
["./formattextconversion.html","Text Format Conversion Settings","The Conversion tab defines how files should be loaded and saved.","./images/zoomimage.jpg"],
["./formattextgeneral.html","Text Format General Settings","The Mask is a set of file types to be associated with this file format.","./images/zoomimage.jpg"],
["./formattextgrammar.html","Text Format Grammar Settings","The Grammar tab defines the syntax of a file.  Grammar elements such as comments and keywords are defined here.  Each grammar element ca...","./images/zoomimage.jpg"],
["./formattextmisc.html","Text Format Miscellaneous Settings","Insert spaces instead of tabs When unmarked, pressing the Tab key inserts a tab character into the file.  When marked, an appropriate number ...","./images/zoomimage.jpg"],
["./glossary.html","Glossary","Base folder The top-most folder on either side of a folder view.  Base folder names appear in the toolbar path edits above each pane of the c...","./images/zoomimage.jpg"],
["./grammars.html","Grammars","A file format specification can include a grammar definition, used for syntax highlighting, and to help define which differences are important.","./images/zoomimage.jpg"],
["./index.html","Welcome","Beyond Compare is a utility for comparing files and folders.  It can help you find and reconcile differences in source code, folders, images ...","./images/zoomimage.jpg"],
["./license_agreement.html","License Agreement","Your use of Beyond Compare is governed by the following Terms and Conditions:","./images/zoomimage.jpg"],
["./license_agreement_7-zip.html","License Agreement: 7-Zip","License for use and distribution 7-Zip Copyright (C) 1999-2010 Igor Pavlov. Licenses for files are:  7z.dll: GNU LGPL + unRAR restriction &#38;nb...","./images/zoomimage.jpg"],
["./license_agreement_fpc.html","License Agreement: FPC","This is the file COPYING.FPC, it applies to the Free Pascal Run-Time Library (RTL) and packages (packages) distributed by members of the Free Pasc...","./images/zoomimage.jpg"],
["./license_agreement_gpl3.html","License Agreement: GPL3","Version 3, 29 June 2007 Copyright &#169; 2007 Free Software Foundation, Inc. &#60;http://fsf.org/&#62; Everyone is permitted to copy and distribute verba...","./images/zoomimage.jpg"],
["./license_agreement_htmlviewer.html","License Agreement: HtmlViewer","Copyright (c) 1995 - 2008 by L. David Baldwin Copyright (c) 1995 - 2008 by Anders Melander (DitherUnit.pas) Copyright (c) 1995 - 2008 by Ron Colli...","./images/zoomimage.jpg"],
["./license_agreement_httpget.html","License Agreement: HTTPGet","This software is provided &#39;as-is&#39;, without any express or implied warranty.  In no event will the author be held liable for any damages arisi...","./images/zoomimage.jpg"],
["./license_agreement_innosetup.html","License Agreement: InnoSetup","Except where otherwise noted, all of the documentation and software included in the Inno Setup package is copyrighted by Jordan Russell.","./images/zoomimage.jpg"],
["./license_agreement_intlck64.html","License Agreement: IntLck64","Copyright (C) 2005 Will DeWitt Jr. &#60;edge@icehouse.net&#62;","./images/zoomimage.jpg"],
["./license_agreement_lgpl.html","License Agreement: LGPL","Version 2, June 1991 Copyright (C) 1991 Free Software Foundation, Inc. 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA Everyone is p...","./images/zoomimage.jpg"],
["./license_agreement_mpl.html","License Agreement: MPL","1. Definitions 1.1. \"Contributor\" means each individual or legal entity that creates, contributes to the creation of, or owns Covered So...","./images/zoomimage.jpg"],
["./license_agreement_pcre.html","License Agreement: PCRE","PCRE is a library of functions to support regular expressions whose syntax and semantics are as close as possible to those of the Perl 5 language.","./images/zoomimage.jpg"],
["./license_agreement_regexpr.html","License Agreement: RegExpr","Author: Andrey V. Sorokin St-Petersburg Russia anso@mail.ru, anso@usa.net http://anso.da.ru http://anso.virtualave.net  This library is deriv...","./images/zoomimage.jpg"],
["./license_agreement_textdiff.html","License Agreement: TextDiff","Author:  Angus Johnson - angusj-AT-myrealbox-DOT-com","./images/zoomimage.jpg"],
["./license_agreement_wavpack.html","License Agreement: WavPack","Copyright (c) 1998 - 2009 Conifer Software All rights reserved.  Redistribution and use in source and binary forms, with or without modificat...","./images/zoomimage.jpg"],
["./license_agreement_wix.html","License Agreement: WiX","Copyright (c) 2004, Outercurve Foundation. This software is released under the Microsoft Reciprocal License (MS-RL) (the \"License\"); you...","./images/zoomimage.jpg"],
["./license_agreement_zlib.html","License Agreement: Zlib","zlib.h -- interface of the &#39;zlib&#39; general purpose compression library","./images/zoomimage.jpg"],
["./managing_sessions.html","Managing Sessions","Beyond Compare automatically saves your most recent sessions so you can come back to them easily.  If you want to retain a session indefinite...","./images/zoomimage.jpg"],
["./moving_bc_to_another_computer.html","Moving Beyond Compare to Another Computer","To copy or move Beyond Compare to a different computer","./images/zoomimage.jpg"],
["./opattrib.html","Attributes","In the Actions menu, the Attributes command modifies various operating system attributes of the selected files and folders.","./images/zoomimage.jpg"],
["./opcompare.html","Content Comparisons","In the Actions menu, the Compare Contents  command performs content comparisons on the selected pairs of files to determine if they match.","./images/zoomimage.jpg"],
["./opcopy.html","Copy","In the Actions menu, the Copy to Right, Copy to Left and Copy to Side commands copy the selected files and folders from one side of the view to th...","./images/zoomimage.jpg"],
["./opcopyto.html","Copy to Folder","In the Actions menu, the Copy to Folder  command copies the selected files and folders to a given folder, optionally with the path intact.&#38;nb...","./images/zoomimage.jpg"],
["./opcopytooutput.html","Copy to Output","In the Actions menu, the Copy to Output  command copies the selected files and folders to the output side.","./images/zoomimage.jpg"],
["./opdelete.html","Delete","In the Actions menu, the Delete  command deletes the selected files and folders from one or both sides of the comparison.","./images/zoomimage.jpg"],
["./opexchange.html","Exchange","In the Actions menu, the Exchange command moves the selected files and folders from one side of the view to the other.","./images/zoomimage.jpg"],
["./opexclude.html","Exclude","In the Actions menu, the Exclude command filters out the selected files and folders from the current session.  It is a handy alternative to o...","./images/zoomimage.jpg"],
["./opmerge.html","Merge","In the Actions menu, the Merge  command performs a merge of the selected files and folders.","./images/zoomimage.jpg"],
["./opmove.html","Move","In the Actions menu, the Move to Right, Move to Left and Move to Side commands move the selected files and folders from one side of the view to th...","./images/zoomimage.jpg"],
["./opmoveto.html","Move to Folder","In the Actions menu, the Move to Folder  command moves the selected files and folders to a given folder, optionally with the path intact.&#38;nbs...","./images/zoomimage.jpg"],
["./opnewfolder.html","New Folder","In the Actions menu, the New Folder  command lets you create a folder at the current position.  If you have a file or closed folder sele...","./images/zoomimage.jpg"],
["./oprename.html","Rename","In the Actions menu, the Rename  command renames the selected files and folders.","./images/zoomimage.jpg"],
["./opsync.html","Synchronize","In the Actions menu, the Synchronize submenu has commands that synchronize the current selection.","./images/zoomimage.jpg"],
["./optionsarchive.html","Archive Type Options","Specify the file types to be associated with each of the supported archive formats.  Pick a format and enter the associated file types separa...","./images/zoomimage.jpg"],
["./optionsbackup.html","Backup Options","Beyond Compare can create a backup of your files before overwriting them during a copy or move operation, or before saving an edited file.  S...","./images/zoomimage.jpg"],
["./optionscolor.html","Appearance Options","Set light or dark theme Select Follow operating system to inherit the setting from the operating system.  The current operating system settin...","./images/zoomimage.jpg"],
["./optionscommand.html","Toolbar, Shortcut, Menu Options","These options allow you to control which commands appear in menus and on toolbars, and allow you to set keyboard shortcuts for commands.  Sin...","./images/zoomimage.jpg"],
["./optionsdircolor.html","Folder View Color, Font Options","These options allow you to customize overall colors and fonts used in folder views.","./images/zoomimage.jpg"],
["./optionsfilecolor.html","File View Color, Font Options","These options allow you to customize visual aspects of the various types of file views.","./images/zoomimage.jpg"],
["./optionsnextdiff.html","Next Difference Options","Set these options to reflect your preferences concerning how to peruse differences.","./images/zoomimage.jpg"],
["./optionsop.html","File Operation Options","Confirmations By default, Beyond Compare prompts for confirmation before performing various actions.  Unmark any of these checkboxes to suppr...","./images/zoomimage.jpg"],
["./optionsopenwith.html","\"Open With\" Application Options","You can configure external applications to appear in the Open With submenu.","./images/zoomimage.jpg"],
["./optionspixcolor.html","Picture Compare Color Options","These options allow you to customize colors used in Picture Compare views.","./images/zoomimage.jpg"],
["./optionsstartup.html","Startup Options","Startup options When Beyond Compare starts up, it normally shows the Home view.  To have the program automatically start up with the same ses...","./images/zoomimage.jpg"],
["./optionstab.html","Tab Options","When working with multiple sessions simultaneously, Beyond Compare can open them in independent windows, or under tabs in a single window.  T...","./images/zoomimage.jpg"],
["./optionstext.html","Text Editing Options","These options apply to Text Compare and Text Merge sessions.","./images/zoomimage.jpg"],
["./optionstweak.html","Tweak Options","Tweaks are advanced or obscure program options that we group here to avoid cluttering other areas.","./images/zoomimage.jpg"],
["./optouch.html","Touch","In the Actions menu, the Touch  command modifies the timestamp (date/time last modified) of the selected files.","./images/zoomimage.jpg"],
["./pix_how_to_compare.html","How to Compare in the Picture Compare","Aligning image content You can compare images that have been resized, rotated, reflected or cropped. Pick Auto Scale  to automatically enlarg...","./images/zoomimage.jpg"],
["./profileamazons3.html","Amazon S3 Profile Settings","Authentication type Controls where credentials are loaded from. Saved S3 credentials Use saved Access key ID and Secret access key. Load from cred...","./images/zoomimage.jpg"],
["./profiledropbox.html","Dropbox Profile Settings","The Description can include any text you want.","./images/zoomimage.jpg"],
["./profileftp.html","FTP Profile Settings","Click the tab for the settings you wish to edit: Global Login Server Connection Proxy Listing Transfer","./images/zoomimage.jpg"],
["./profileftpconnection.html","FTP Profile Connection Settings","These settings control how the connection is made to the remote server.","./images/zoomimage.jpg"],
["./profileftpglobal.html","FTP Profile Global Settings","Anonymous logins Email address When connecting to anonymous FTP sites, it is customary to include your email address as the password.  Specif...","./images/zoomimage.jpg"],
["./profileftplisting.html","FTP Profile Listing Settings","Beyond Compare parses the plain text directory listings sent from the FTP server in order to determine the remote folder structure.  Unfortun...","./images/zoomimage.jpg"],
["./profileftplogin.html","FTP Profile Login Settings","Protocol Specify FTP or one of the secure FTP options: SSL or SSH. Port Override if you don&#39;t want to use the standard value for the specified pro...","./images/zoomimage.jpg"],
["./profileftpproxy.html","FTP Profile Proxy Settings","Use proxy Mark if connections should use FTP Proxy protocol.  If you are not on a Local Area Network (LAN) or Wide Area Network (WAN), leave ...","./images/zoomimage.jpg"],
["./profileftpserver.html","FTP Profile Server Settings","Filenames are case sensitive Mark to require filename character case to be the same in order to line up in the comparison. Encoding Specify the ch...","./images/zoomimage.jpg"],
["./profileftptransfer.html","FTP Profile Transfer Settings","These settings control how files are transferred to and from the FTP server.","./images/zoomimage.jpg"],
["./profileonedrive.html","OneDrive Profile Settings","The Description can include any text you want.","./images/zoomimage.jpg"],
["./profilesvn.html","Subversion Profile Settings","URL of repository, Revision Specify parameters for your account. The Description can include any text you want.","./images/zoomimage.jpg"],
["./profilewebdav.html","WebDAV Profile Settings","URL, Username, Password, Recursive listings Specify parameters for your account. The Description can include any text you want.","./images/zoomimage.jpg"],
["./regular_expression_reference.html","Regular Expression Reference","Regular Expressions are a powerful way to define patterns for searching and matching.  Beyond Compare allows you to use regular expressions w...","./images/zoomimage.jpg"],
["./remote_services.html","Remote Services","Remote services include FTP and Subversion. FTP sites are represented using the standard syntax: ftp://username@ftp.hostname.com ftp://username:pa...","./images/zoomimage.jpg"],
["./rules_vs_file_formats.html","Rules vs. File Formats","In Beyond Compare, file formats describe the syntax of specific kinds of files by defining elements.  File formats are typically picked autom...","./images/zoomimage.jpg"],
["./sample_regular_expressions.html","Sample Regular Expressions","Expression Meaning ^abc Match \"abc\" at beginning of line abc$ Match \"abc\" at end of line ^abc$ Match the line \"abc\" ...","./images/zoomimage.jpg"],
["./sample_scripts.html","Sample Scripts","The following are some sample scripts to show how Beyond Compare can use scripts.  You can either use these scripts as is or model your own s...","./images/zoomimage.jpg"],
["./scheduling_a_script.html","Scheduling a Script","You can use Beyond Compare&#39;s script processor to perform certain tasks, such as synchronizing folders, without interaction.  For example, to ...","./images/zoomimage.jpg"],
["./scripting_reference.html","Scripting Reference","A script is a simple text file containing a list of commands which can control the program and automatically perform file operations or produce re...","./images/zoomimage.jpg"],
["./scripts.html","Scripts","Beyond Compare provides a script processing feature which allows you to automate routine tasks.  A script is a simple text file containing a ...","./images/zoomimage.jpg"],
["./searching_for_text.html","Searching for Text","To search for text in a Text Compare session, pick Search &#62; Find .  Type the text or a regular expression pattern in the edit, or pick a p...","./images/zoomimage.jpg"],
["./sessiondir.html","Folder Compare Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
["./sessiondircomparison.html","Folder Compare Comparison Settings","These settings control what is considered a difference in a folder session.","./images/zoomimage.jpg"],
["./sessiondirhandling.html","Folder Compare Handling Settings","Folder handling Automatically scan subfolders in background causes folders to be read in the background when a comparison is loaded.  This wa...","./images/zoomimage.jpg"],
["./sessiondirmerge.html","Folder Merge Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
["./sessiondirmergecomparison.html","Folder Merge Comparison Settings","These settings control what is considered a difference in a folder session.","./images/zoomimage.jpg"],
["./sessiondirmergehandling.html","Folder Merge Handling Settings","Folder handling Automatically scan subfolders in background causes folders to be read in the background when a comparison is loaded.  This wa...","./images/zoomimage.jpg"],
["./sessiondirmergemisc.html","Folder Merge Miscellaneous Settings","To override file format associations The Enabled file formats list lets you override which file formats will be used by this folder session. ...","./images/zoomimage.jpg"],
["./sessiondirmergenamefilter.html","Folder Merge Name Filter Settings","You can include or exclude folders and files based on their names by using one or more file masks.","./images/zoomimage.jpg"],
["./sessiondirmergeotherfilters.html","Folder Merge Other Filter Settings","You can exclude files from a folder session based on criteria other than their names.  Click the New button to add an Other Filter Item.","./images/zoomimage.jpg"],
["./sessiondirmergespecs.html","Folder Merge Spec Settings","Specify the base folders to be merged. Merge to defines the destination folder of the merge results. The Description can include any text you want.","./images/zoomimage.jpg"],
["./sessiondirmisc.html","Folder Compare Miscellaneous Settings","To force a different alignment By default, a folder session aligns files and subfolders by name, left and right.  Click the New button to add...","./images/zoomimage.jpg"],
["./sessiondirnamefilter.html","Folder Compare Name Filter Settings","You can include or exclude folders and files based on their names by using one or more file masks.","./images/zoomimage.jpg"],
["./sessiondirotherfilters.html","Folder Compare Other Filter Settings","You can exclude files from a folder session based on criteria other than their names.  Click the New button to add an Other Filter Item.","./images/zoomimage.jpg"],
["./sessiondirspecs.html","Folder Compare Spec Settings","Specify the base folders to be compared. Mark Disable editing to protect content from being changed on disk.  New child sessions will be affe...","./images/zoomimage.jpg"],
["./sessiondirsync.html","Folder Sync Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
["./sessiondirsynccomparison.html","Folder Sync Comparison Settings","These settings control what is considered a difference in a folder session.","./images/zoomimage.jpg"],
["./sessiondirsynchandling.html","Folder Sync Handling Settings","Folder handling Sync empty folders will affect folders without content or whose entire contents have been filtered out. Expand subfolders when loa...","./images/zoomimage.jpg"],
["./sessiondirsyncmisc.html","Folder Sync Miscellaneous Settings","To force a different alignment By default, a folder session aligns files and subfolders by name, left and right.  Click the New button to add...","./images/zoomimage.jpg"],
["./sessiondirsyncnamefilter.html","Folder Sync Name Filter Settings","You can include or exclude folders and files based on their names by using one or more file masks.","./images/zoomimage.jpg"],
["./sessiondirsyncops.html","Folder Sync Synchronize Settings","Operations Presets You can use one of the predefined sync methods described in the overview or create a custom one.","./images/zoomimage.jpg"],
["./sessiondirsyncotherfilters.html","Folder Sync Other Filter Settings","You can exclude files from a folder session based on criteria other than their names.  Click the New button to add an Other Filter Item.","./images/zoomimage.jpg"],
["./sessiondirsyncspecs.html","Folder Sync Spec Settings","Specify the base folders to be synced. The Description can include any text you want.","./images/zoomimage.jpg"],
["./sessionhex.html","Hex Compare Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
["./sessionhexcomparison.html","Hex Compare Comparison Settings","These settings control how the files are compared.","./images/zoomimage.jpg"],
["./sessionhexformats.html","Hex Compare File Format Settings","Specify the file format to be used when reading the left and/or right files.  The default selection is Detected, which means the file format ...","./images/zoomimage.jpg"],
["./sessionhexspecs.html","Hex Compare Spec Settings","Specify the files to be compared. Mark Disable editing to protect content from being changed on disk. The Description can include any text you want.","./images/zoomimage.jpg"],
["./sessionmedia.html","Media Compare Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
["./sessionmediaimportance.html","Media Compare Importance Settings","These settings control which differences you consider important.","./images/zoomimage.jpg"],
["./sessionmediaspecs.html","Media Compare Spec Settings","Specify the files to be compared. The Description can include any text you want.","./images/zoomimage.jpg"],
["./sessionpix.html","Picture Compare Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
["./sessionpixformats.html","Picture Compare File Format Settings","Specify the file format to be used when reading the left and/or right files.  The default selection is Detected, which means the file format ...","./images/zoomimage.jpg"],
["./sessionpixreplacements.html","Picture Compare Replacement Settings","Replacements identify changes that should be considered unimportant.  You can specify the color to match on one side and the color that repla...","./images/zoomimage.jpg"],
["./sessionpixspecs.html","Picture Compare Spec Settings","Specify the files to be compared. The Description can include any text you want.","./images/zoomimage.jpg"],
["./sessionreg.html","Registry Compare Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
["./sessionregspecs.html","Registry Compare Spec Settings","Specify the files to be compared. The Description can include any text you want.","./images/zoomimage.jpg"],
["./sessiontable.html","Table Compare Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
["./sessiontablecolumns.html","Table Compare Column Settings","Each line in the display represents a comparison column, and shows:","./images/zoomimage.jpg"],
["./sessiontableformats.html","Table Compare File Format Settings","Specify the file format to be used when reading the left and/or right files.  The default selection is Detected, which means the file format ...","./images/zoomimage.jpg"],
["./sessiontablerows.html","Table Compare Row Settings","These settings control the algorithm for aligning rows in the comparison when no keys are defined.","./images/zoomimage.jpg"],
["./sessiontablesheets.html","Table Compare Sheet Settings","Each line in the display represents a comparison sheet, and shows:","./images/zoomimage.jpg"],
["./sessiontablespecs.html","Table Compare Spec Settings","Specify the files to be compared. Mark Disable editing to protect content from being changed on disk. The Description can include any text you want.","./images/zoomimage.jpg"],
["./sessiontext.html","Text Compare Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
["./sessiontextalignment.html","Text Compare Alignment Settings","These settings control the algorithm for aligning lines in the comparison.","./images/zoomimage.jpg"],
["./sessiontextformats.html","Text Compare File Format Settings","Specify the file format to be used when reading the left and/or right files.  The default selection is Detected, which means the file format ...","./images/zoomimage.jpg"],
["./sessiontextimportance.html","Text Compare Importance Settings","These settings control which differences you consider important in the current session.  Important differences will be colored red in the com...","./images/zoomimage.jpg"],
["./sessiontextmerge.html","Text Merge Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
["./sessiontextmergealignment.html","Text Merge Alignment Settings","These settings control the algorithm for aligning lines in the comparison.","./images/zoomimage.jpg"],
["./sessiontextmergeformats.html","Text Merge File Format Settings","Specify the file format to be used when reading the input files.  The default selection is Detected, which means the file format will be sele...","./images/zoomimage.jpg"],
["./sessiontextmergeimportance.html","Text Merge Importance Settings","These settings control which differences you consider important in the current session.  Important differences will be colored red in the com...","./images/zoomimage.jpg"],
["./sessiontextmergespecs.html","Text Merge Spec Settings","Specify the files to be merged. Merge to defines the destination file of the merge results. The Description can include any text you want.","./images/zoomimage.jpg"],
["./sessiontextreplacements.html","Text Compare Replacement Settings","Replacements identify repetitive changes that should be considered unimportant.  You can specify the text to match on one side and the text t...","./images/zoomimage.jpg"],
["./sessiontextspecs.html","Text Compare Spec Settings","Specify the files to be compared. Mark Disable editing to protect content from being changed on disk. The Description can include any text you want.","./images/zoomimage.jpg"],
["./sessionver.html","Version Compare Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
["./sessionverimportance.html","Version Compare Importance Settings","These settings control which differences you consider important.","./images/zoomimage.jpg"],
["./sessionverspecs.html","Version Compare Spec Settings","Specify the files to be compared. The Description can include any text you want.","./images/zoomimage.jpg"],
["./session_settings.html","Session Settings","To edit session settings Pick Session &#62; Session Settings . Modify the desired settings on each tab. The dropdown list at the bottom of the dial...","./images/zoomimage.jpg"],
["./settings_reference.html","Settings Reference","Beyond Compare is highly configurable, and it sometimes can be hard to know where to go in the program to change a specific setting.  Here&#39;s ...","./images/zoomimage.jpg"],
["./sharing_sessions.html","Sharing Sessions","Multiple users can share sessions by using a shared sessions file.","./images/zoomimage.jpg"],
["./snapshots.html","Snapshots","In the Tools menu, the Save Snapshot  command saves a compressed read-only listing of the specified folder and all of its subfolders, includi...","./images/zoomimage.jpg"],
["./specs.html","Specs","A Spec is the name of a folder or file.  Beyond Compare supports several different types of specs.","./images/zoomimage.jpg"],
["./standard_vs_pro.html","Standard vs Pro Editions","The Standard edition of Beyond Compare is a powerful full-featured comparison tool, not a stripped-down \"lite\" version.  The Standa...","./images/zoomimage.jpg"],
["./support_ordering_and_license.html","Support, Ordering, and License","For the latest version of Beyond Compare and for other news about the program, visit our web site at:  www.scootersoftware.com","./images/zoomimage.jpg"],
["./table_working_with_multiple.html","Working with Multiple Sheets","When you are comparing files that contain multiple sheets, click the tabs at the bottom of the Table Compare view to switch between comparison she...","./images/zoomimage.jpg"],
["./using_bc.html","Using Beyond Compare","Beyond Compare handles a wide variety of comparison tasks.  It has specialized views for different kinds of files and different approaches to...","./images/zoomimage.jpg"],
["./using_text_merge.html","Using Text Merge","Once Beyond Compare has completed the comparison it will show up to four panes:  The left, center, and right panes at the top, with an output...","./images/zoomimage.jpg"],
["./viewdir.html","Folder Compare Overview","A Folder Compare session compares two folder structures side-by-side, in a variation of the familiar Windows Explorer style.  The comparison ...","./images/zoomimage.jpg"],
["./viewdirmerge.html","Folder Merge Overview","A Folder Merge session displays two or three folder structures side-by-side.  The left and right panes hold two versions of a folder structur...","./images/zoomimage.jpg"],
["./viewdirsync.html","Folder Sync Overview","A Folder Sync session is a specialized folder session that synchronizes folders by copying or deleting files.  Once you set up a Folder Sync ...","./images/zoomimage.jpg"],
["./viewhex.html","Hex Compare Overview","A Hex Compare session visually compares the raw content of two files, either in a side-by-side or over-under layout.  It displays file conten...","./images/zoomimage.jpg"],
["./viewhome.html","Home View","When you open a new window or tab, Beyond Compare displays the Home view:","./images/zoomimage.jpg"],
["./viewother.html","Other View Types","Media Compare A Media Compare session compares two media files with differences in tag fields highlighted. FLAC, MP3, and MP4/AAC files are suppor...","./images/zoomimage.jpg"],
["./viewpix.html","Picture Compare Overview","A Picture Compare session compares a pair of image files visually, showing the differences between them.","./images/zoomimage.jpg"],
["./viewreg.html","Registry Compare Overview","A Registry Compare session compares live registries on your computer or other computers on your network, and .reg export files, either in a side-b...","./images/zoomimage.jpg"],
["./viewtable.html","Table Compare Overview","A Table Compare session compares text files containing tabular data, such as .csv (comma separated values) files, in a side-by-side or over-under ...","./images/zoomimage.jpg"],
["./viewtext.html","Text Compare Overview","A Text Compare session visually compares two text files, in a side-by-side or over-under layout.  It helps you analyze and reconcile differen...","./images/zoomimage.jpg"],
["./viewtextedit.html","Text Edit Overview","A Text Edit view is a single-pane text editor.  See also Text Edit Commands Text Format Settings Text Editing Options","./images/zoomimage.jpg"],
["./viewtextmerge.html","Text Merge Overview","A Text Merge session contains two or three non-editable source panes and an editable output pane.  The left and right panes hold two versions...","./images/zoomimage.jpg"],
["./viewtextpatch.html","Text Patch Overview","A Text Patch view recreates a comparison represented in a patch file.  Patch files can be generated using a Text Compare report or a another ...","./images/zoomimage.jpg"],
["./walking_through_differences.html","Walking Through Differences","In the Search menu, the Next Difference Section  and Previous Difference Section  commands help you step through all the differences in ...","./images/zoomimage.jpg"],
["./whats_new.html","What&#39;s New","Here are some of the significant new features in Beyond Compare 5.  Items flagged with  are only available in the Pro edition.","./images/zoomimage.jpg"],
["./where_settings_are_stored.html","Where Settings are Stored on your Computer","Beyond Compare stores your sessions, customized file formats and other preferences as .xml files in its settings folder.  A quick way of find...","./images/zoomimage.jpg"]];
